@@ -105,11 +105,11 @@ class App:
             self.add_middleware(DefaultMiddleware)
 
         self.collections = []
-        
+
         # def serve_static(self, scope, recieve, send, path):
         #     ...
-        
-        self.add_route("/static", self.static_app)
+
+        # self.add_route("/static", self.static_app)
 
     async def wsgi_app(self, scope, recieve, send):
         request = Request(scope, recieve=recieve)
@@ -119,6 +119,9 @@ class App:
         await response(scope, recieve, send)
 
     async def __call__(self, scope, recieve, send):
+        if "static" in scope["path"]:
+            await self.static_app(scope, recieve, send)
+
         await self.middleware(scope, recieve, send)
 
     def handle_request(self, request):
